@@ -84,6 +84,10 @@ class NetworkTests(unittest.TestCase):
                                               cluster=sentinel.cluster,
                                               subcluster=sentinel.subcluster)
 
+    def test_bad_station_numbers(self):
+        bad_number = 1
+        self.assertRaises(Exception, self.network.station_numbers, country=bad_number, allow_stale=False)
+
     def test_bad_stations(self):
         self.network.stations()
         self.assertEqual(self.network._all_stations, self.network.stations())
@@ -130,13 +134,11 @@ class StationTests(unittest.TestCase):
         self.assertEqual(len(self.station.detectors()), self.station.n_detectors())
         self.assertEqual(self.station.detectors()[0].keys(), keys)
         self.assertEqual(self.station.detectors(date(2011, 1, 1))[0].keys(), keys)
-        self.assertEqual(self.station.detectors()[0]['alpha'], 225)
         self.assertEqual(self.station.detectors(date(2011, 1, 1))[0]['alpha'], 225)
 
     def test_location(self):
         keys = ['latitude',  'altitude', 'longitude']
         self.assertEqual(self.station.location().keys(), keys)
-        self.assertEqual(self.station.location()['latitude'], 52.355928561847)
         self.assertEqual(self.station.location(date(2002, 1, 1))['latitude'],
                          52.3559179545407)
 
